DEFAULTS = {
    'DEFAULT_FORMAT': True,
    'MESSAGE_FORMAT': "<b><green>{time}</green> <cyan>{message}</cyan></b>"
}

class Settings:
    def __init__(self, settings):
        self.settings = getattr(settings, 'DJANGO_LOGGING_MIDDLEWARE', {})
        self.set_settings()

    def set_settings(self):
        if self.settings == {}:
            self.DEFAULT_FORMAT = DEFAULTS['DEFAULT_FORMAT']
            self.MESSAGE_FORMAT = DEFAULTS['MESSAGE_FORMAT']
        elif 'DEFAULT_FORMAT' not in list(self.settings.keys()):
            self.DEFAULT_FORMAT = DEFAULTS['DEFAULT_FORMAT']
            self.MESSAGE_FORMAT = DEFAULTS['MESSAGE_FORMAT']
        elif not isinstance(self.settings['DEFAULT_FORMAT'], bool):
            self.DEFAULT_FORMAT = DEFAULTS['DEFAULT_FORMAT']
            self.MESSAGE_FORMAT = DEFAULTS['MESSAGE_FORMAT']
        elif 'DEFAULT_FORMAT' in list(self.settings.keys()):
            if not self.settings['DEFAULT_FORMAT'] and 'MESSAGE_FORMAT' in list(self.settings.keys()):
                self.DEFAULT_FORMAT = self.settings['DEFAULT_FORMAT']
                self.MESSAGE_FORMAT = self.settings['MESSAGE_FORMAT']
            elif self.settings['DEFAULT_FORMAT'] and 'MESSAGE_FORMAT' not in list(self.settings.keys()):
                self.DEFAULT_FORMAT = self.settings['DEFAULT_FORMAT']
                self.MESSAGE_FORMAT = DEFAULTS['MESSAGE_FORMAT']
            else:
                self.DEFAULT_FORMAT = self.settings['DEFAULT_FORMAT']
                self.MESSAGE_FORMAT = DEFAULTS['MESSAGE_FORMAT']
        else:
            self.DEFAULT_FORMAT = self.settings['DEFAULT_FORMAT']
            self.MESSAGE_FORMAT = self.settings['MESSAGE_FORMAT']




import sys

from django.conf import settings as _settings
from loguru import logger

from .settings import Settings


settings = Settings(_settings)
logger.remove(0)
logger.add(sys.stderr, colorize=True, format=settings.MESSAGE_FORMAT)

class DjangoLoggingMiddleware:
    
    def __init__(self, get_response):
        self.get_response = get_response

    def __call__(self, request):
        logger.info(f"Request URL: {request.get_raw_uri()}")
        logger.info(f"Request METHOD: {request.method}")
        logger.info(f"Request HEADERS: {request.headers}")
        logger.info(f"Request GET data: {request.GET}")
        logger.info(f"Request POST data: {request.POST}")
        logger.info(f"Request FILES data: {request.FILES}")

        response = self.get_response(request)
        logger.info(f"Request USER: {request.user}")
        logger.info(f"Response STATUS_CODE: {response.status_code}")
        try:
            logger.info(f"Response MEDIA_TYPE: {response.accepted_media_type}")
            logger.info(f"Response _MEDIA_TYPE: {response.charset}")
            logger.info(f"Response DATA: {response.data}")
        except:
            logger.info(f"Response MEDIA_TYPE: {response.charset}")
            logger.info(f"Response DATA: {response.content}")
        
        return response



import setuptools

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setuptools.setup(
    name="django-logging-middleware", # Replace with your own username
    version="0.1.1a1",
    author="Rifat Fazlutdinov",
    author_email="rifatfazlutdinov@gmail.com",
    description="A small package to log django requests and responses",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/fearsd/django-logging-middleware",
    packages=setuptools.find_packages(exclude=['tests*']),
    install_requires=["django>=3.0", "loguru"],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
)
